@@ -18,7 +18,7 @@ def add_cylinder(self, cylinder: Cylinder) -> Tuple[int, int]:
     vector = normal.scaled(H)
     x0, y0, z0 = start
     dx, dy, dz = vector
-    tag = self.factory.addCylinder(x0, y0, z0, dx, dy, dz, R)
+    tag = self.occ.addCylinder(x0, y0, z0, dx, dy, dz, R)
     return 3, tag
 
 
@@ -26,7 +26,7 @@ def add_sphere(self, sphere: Sphere) -> Tuple[int, int]:
     """Add a sphere to the model."""
     x, y, z = sphere.point
     R = sphere.radius
-    tag = self.factory.addSphere(x, y, z, R)
+    tag = self.occ.addSphere(x, y, z, R)
     return 3, tag
 
 
@@ -36,7 +36,7 @@ def add_box(self, box: Box) -> Tuple[int, int]:
     x = x0 - 0.5 * box.xsize
     y = y0 - 0.5 * box.ysize
     z = z0 - 0.5 * box.zsize
-    tag = self.factory.addBox(x, y, z, box.xsize, box.ysize, box.zsize)
+    tag = self.occ.addBox(x, y, z, box.xsize, box.ysize, box.zsize)
     return 3, tag
 
 
@@ -62,7 +62,7 @@ class CSGModel(Model):
 
     """
 
-    def __init__(self, tree: dict, name: str, **kwargs):
+    def __init__(self, tree: dict, name: str, **kwargs) -> None:
         super().__init__(name, **kwargs)
         self._tree = None
         self.tree = tree
@@ -128,15 +128,15 @@ class CSGModel(Model):
                     operands[index] = self.add(operand)
 
             if operation == 'union':
-                result = self.factory.fuse(operands[:-1], operands[-1:])
+                result = self.occ.fuse(operands[:-1], operands[-1:])
                 return result[0][0]
 
             if operation == 'difference':
-                result = self.factory.cut(operands[:-1], operands[-1:])
+                result = self.occ.cut(operands[:-1], operands[-1:])
                 return result[0][0]
 
             if operation == 'intersection':
-                result = self.factory.intersect(operands[:-1], operands[-1:])
+                result = self.occ.intersect(operands[:-1], operands[-1:])
                 return result[0][0]
 
         walk(self.tree)
